

log using "C:\Users\chris\Dropbox\Research\Diffusion and Fortifications\border and domestic politics\logfile-jcr.txt", text replace





****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************
* WHY DO LEADERS BUILD WALLS?
*
* Chris Linebarger and Alex Braithwaite
*
* November 22, 2021
*
* Journal of Conflict Resolution
*
****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************************************************



************************
*NOTES
*
*The main models appear sequentially throughout this do-file.  Most diagnostic tests are found with their associated model.  Descriptive stats for leader model found with leader model; descriptives stats for main model are in the "OTHER APPENDIX MATERIAL" below.
*
*Robustness tests and alternative specifications are found below, in the "OTHER APPENDIX MATERIAL" section.
*
************************



************************************************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************************************************
*MAIN ANALYSIS
************************************************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************************************************



#delimit;
use "C:\Users\chris\Dropbox\Research\Diffusion and Fortifications\data\why do leaders build walls - JCR - FINAL.dta", clear;



******************************************************************************************************************
******************************************************************************************************************
*GENERATE LEADER INSECURITY (TABLE 1)
******************************************************************************************************************
******************************************************************************************************************

*WEIBULL MODEL (TABLE 1)

#delimit;
bysort leaderid (year) : gen yearsinpower = _n;
stset yearsinpower, fail(leadertrans==1) exit(exityear)  id(leaderid) ;
streg pct electcount leaderexits age , distribution(weibull)  robust cl(leaderid);
predict haz, hazard;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\leaderhazard", 
		*stnum(replace coef=exp( coef)) title("leaderhazard") ctitle("weibull") addnote("Probability Levels Two-tailed")
		*e(all) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) stats(coef se) bdec(3) sdec(3) excel replace;

*generate descriptive statistics for leader insecurity model (APPENDIX TABLE 2);
gen leadersample = e(sample);
		
sort leaderid year;
sum haz;



rename haz p_builder;

******************************************************************************************************************
******************************************************************************************************************
*LOGIT ANALYSIS (TABLE 2)
******************************************************************************************************************
******************************************************************************************************************

*prepare data for analysis;
#delimit;
xtset leaderid year;
sum p_builder;





*********************************************************;
*MODEL 1: construction onset, pooled logit ;
*********************************************************;

*M1;
logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, robust cl(leaderid);


*ID Sample;
	gen sample1 = e(sample);

*Export model;
		*#delimit;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\model1.xls", 
		*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
		*e(all)  excel replace;

		
		
		
		
*********************;
*Obtain changes in each variable;
*********************;

*insecurity;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=1 p_builder=(0.0815363		0.2736875) )vsquish saving(all, replace);




*lnpop;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=1 lnpop=(0.736573		3.810987) )vsquish saving(all, replace);





*neighdem;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=1 neighdem=(-4.420037		7.493769) )vsquish saving(all, replace);




*lninequality;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=1 lninequality=(-3.110034		0.883594) )vsquish saving(all, replace);



*post911;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=1 post=(0 1) )vsquish saving(all, replace);





*ethsim;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0  ethsim=(0 1 ))vsquish saving(all, replace);




*lninc;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0 ethsim=1 lninc =(0		0.877165))vsquish saving(all, replace);




*annual onset count;
margins  if sample1==1 , at((mean) _all rightwing=0 dem=0 neighciv=0 cwinc=0 ethsim=1  annualwallonsets =(0	3.890121))vsquish saving(all, replace);




*********************;
*Outlier diagnostics appearing in Appendix (Appendix FIGURE 1A);
*********************;

*Identify outliers;
gen uniqueid = _n if sample1==1;
predict p;
predict hat, hat;
predict dbeta, dbeta;

*Plot outliers;
sum hat;
scatter hat p if sample1==1,  scheme(s1mono) xtitle("Pr(Construction onset)") ytitle("Leverage")  ;
	*graph export "C:\Users\chris\Dropbox\Research\Diffusion and Fortifications\border and domestic politics\leverage1.pdf",replace;


*list outliers;
list ccode year leader if unique==8652;
list ccode leader year uniqueid if hat >=.2 & hat !=.;
list ccode1 year uniqueid leader if p > .5 & p!=.;

*recompute with outliers removed (Appendix TABLE 5, MODEL 1);
logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* if (hat <=0.2), robust cl(leaderid);


*Export model;
		*#delimit;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\robust1.xls", 
		*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
		*e(all)  excel replace;

drop unique p dbeta uniqueid hat;




*********************;
* VIF (Appendix TABLE 4);
*********************;
*Check VIF and Tolerance;
	#delimit;
	collin   p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*	if   sample1==1 ;


	
	
*********************	;
*MAIN PAPER FIGURE 1 A;
*********************	;
	

margins , predict(pr) at(p_builder=(0(.05).5));

marginsplot, title("") recastci(rarea) plot1opts(msymbol(none) lp(dash) lw(thick)) ci1opts(fintensity(40)) scheme(s1mono) xlabel(0(.5)2.5) ytitle("Percentage of Observations") addplot(histogram p_builder if p_builder < .5, percent yaxis(2) yscale(alt) fcolor(%15) ytitle("Pr(Wall construction)")) legend( off )	;

	
	
	
*********************	;
*USA simulation (main text);
*********************	;

*run model without hungary;
logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* if ccode !=2 , robust cl(leaderid) ;
	gen samplesim1 = e(sample);

	*summary stats;
	sum startwallonset   p_builder leaderexits pct   age right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 lnpop if  ccode==2;

	*compute values;
	*-1 to +1	Std Dev;
	margins, predict(pr) at((mean) _all p_builder=( .0812467  .2740929)    right=1 lnpop= 5.494237  lnref= 1.996969  democracy=1  neighcivwar=0  neighdem= 4.962121     neighcount=2  cwinc=0 lninequality=2.305954   );

	
	
*********************;	
*Hungary simulation (main text);
*********************	;

*run model without hungary;
logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* if ccode !=310 , robust cl(leaderid) ;
	gen samplesim2 = e(sample);

	*summary stats;
	sum startwallonset   p_builder leaderexits pct  age right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 lnpop if  ccode==310;

	*compute values;
	*-1 to +1		Std Dev;
	margins, predict(pr) at((mean) _all p_builder=(.0812105 .2741111)    right=0 lnpop=     2.33488    lnref=  3.117694   democracy=1  neighcivwar=0  neighdem=   3.170707     neighcount= 4.363636    cwinc=0 lninequality= -.1963354    );


	
	
	

*********************************************************;
*MODEL 2: construction onset, random effects;
*********************************************************;


	
#delimit;
xtlogit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, re;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\model2.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;



*********************************************************;
*MODEL 3: construction onset, fixed effects;
*********************************************************;


	
#delimit;			
xtlogit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, fe;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\robust2.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
			
			
			
			
			
			
			
			
			
			


************************************************************;
*MODEL 4: wall construction, pooled logit;
************************************************************;


logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , robust cl(leaderid);
	
	gen sample2 = e(sample);

	
	*Export model;
		*#delimit;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\robust4.xls", 
		*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
		*e(all)  excel replace;

	
*********************	;
*MAIN PAPER FIGURE 1 B;
*********************	;

margins , predict(pr) at(p_builder=(0(.05).5));

marginsplot, title("") recastci(rarea) plot1opts(msymbol(none) lp(dash) lw(thick)) ci1opts(fintensity(40)) scheme(s1mono) xlabel(0(.5)2.5) ytitle("Percentage of Observations") addplot(histogram p_builder if p_builder < .5, percent yaxis(2) yscale(alt) fcolor(%15) ytitle("Pr(Wall construction)")) legend( off )	;
	
	

	


*********************;
*Outlier diagnostics appearing in Appendix (Appendix FIGURE 1B);
*********************;


*Identify outliers;
gen uniqueid = _n if sample2==1;
predict p;
predict hat, hat;
predict dbeta, dbeta;
scatter hat p if sample2==1,  scheme(s1mono) xtitle("Pr(Ongoing construction)") ytitle("Leverage") ;
*scatter dbeta uniqueid,  scheme(s1mono) 


			*graph export "C:\Users\chris\Dropbox\Research\Diffusion and Fortifications\border and domestic politics\leverage2.pdf",replace;
			
			
	
list ccode year leader if unique==8652;
list ccode leader year uniqueid if hat >=.2 & hat !=.;
list ccode1 year uniqueid leader if p > .5 & p!=.;
		
sum hat;


*********************;
*recompute with outliers removed (Appendix TABLE 5, MODEL 4);
*********************;
logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears*  if (hat <=1.5 )    , robust cl(leaderid);

	
	
drop unique p  dbeta uniqueid	;
	
	



************************************************************;
*MODEL 5: wall construction, random effects;
************************************************************;
#delimit;
xtlogit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , re;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\robust5.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;	

			
			
	
*********************************************************	;	
*MODEL 6: 	wall construction, fixed effects	;
*********************************************************;
	
#delimit;			
xtlogit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , fe;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\robust6.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;

			
			
			
			
			


************************************************************************************************************************************************************************************************************************************;
************************************************************************************************************************************************************************************************************************************;
*OTHER DIANOSTICS AND ROBUSTNESS TESTS (APPENDIX MATERIAL);
************************************************************************************************************************************************************************************************************************************;
************************************************************************************************************************************************************************************************************************************;
			
			
******************************************************************************************************************;
******************************************************************************************************************;
*DESCRIPTIVE STATISTICS (APPENDIX TABLE 2);
******************************************************************************************************************;
******************************************************************************************************************;

*summary stats;
sum startwallonset wallconstruction  p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets if sample1==1;
		

	
	
	
	
	
	
******************************************************************************************************************;
******************************************************************************************************************	;
*REGIME TYPE MODELS	(APPENDIX TABLE 6)	;
******************************************************************************************************************;
******************************************************************************************************************;
	
#delimit;
	
*M1;
	logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* if dem==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime1.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
	
	
*M2;
	logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*  if auto==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime2.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
	
	
*M3;
	logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* if anoc==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime3.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
	

#delimit;
	
*M4;	
	logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets wallconstructionyears* if dem==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime4.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
		
*M5;
	logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets wallconstructionyears* if auto==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime5.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
		
*M6;
	logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets wallconstructionyears* if anoc==1, robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\regime6.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
	

	
	
	
******************************************************************************************************************;
******************************************************************************************************************	;	
*POLITY MODELS	(APPENDIX TABLE 7);
******************************************************************************************************************;
******************************************************************************************************************;
	
#delimit;
*M1;
	logit startwallonset c.p_builder##c.polity2  right lnpop lnref   neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears* , robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\polity1.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;


*M4;		
	logit wallconstruction c.p_builder##c.polity2  right lnpop lnref   neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets wallconstructionyears* , robust cl(leaderid);
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\polity2.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
		
	
	



	
******************************************************************************************************************;
******************************************************************************************************************	;
*ALTERNATE CLUSTERING (APPENDIX TABLE 8)		;
******************************************************************************************************************;
******************************************************************************************************************;

**Requires cgmlogit package to run (Cameron et al 2012);

*M1;
#delimit;
cgmlogit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*,  cl(leaderid region);
			*#delimit;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\robust5.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;

	
*M4;
#delimit;
cgmlogit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears*,  cl(leaderid region);
			*#delimit;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\robust6.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;











			
************************************************************************************************************************************************************************************************************************************;
************************************************************************************************************************************************************************************************************************************;
*ROBUSTNESS TEST WITH ALTERNATIVE CHARACTERIZATION OF LEADER SECURITY (APPENDIX TABLES 9 and 10);
************************************************************************************************************************************************************************************************************************************;
************************************************************************************************************************************************************************************************************************************;




#delimit;
use "C:\Users\chris\Dropbox\Research\Diffusion and Fortifications\data\why do leaders build walls - JCR - FINAL", clear;



#delimit;
xtset leaderid year;

******************************************************************************************************************
******************************************************************************************************************
*GENERATE LEADER INSECURITY (TABLE 9)
******************************************************************************************************************
******************************************************************************************************************

*WEIBULL MODEL

#delimit;
bysort leaderid (year) : gen yearsinpower = _n;
stset yearsinpower, fail(leadertrans==1) exit(exityear)  id(leaderid) ;
streg pct  leaderexits  , distribution(weibull)  robust cl(leaderid);
predict haz, hazard;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\leaderhazard-alternate", 
		*stnum(replace coef=exp( coef)) title("leaderhazard") ctitle("weibull") addnote("Probability Levels Two-tailed")
		*e(all) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) stats(coef se) bdec(3) sdec(3) excel replace;

sort leaderid year;
sum haz;



rename haz p_builder;

******************************************************************************************************************
******************************************************************************************************************
*MAIN ANALYSIS (APPENDIX TABLE 10)
******************************************************************************************************************
******************************************************************************************************************

#delimit;
xtset leaderid year;
sum p_builder;



*********************************************************
*MODEL 1: construction onset pooled logit 
*********************************************************
#delimit;

logit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, robust cl(leaderid);


*ID Sample;
	gen sample1 = e(sample);

*Export model;
		*#delimit;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\1.xls", 
		*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
		*e(all)  excel replace;

		
		
	
	
	

*********************************************************;
*MODEL 2: construction onset random effects;
*********************************************************;


	
#delimit;
xtlogit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, re;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\2.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;



*********************************************************;
*MODEL 3: construction onset fixed effects;
*********************************************************;


	
#delimit;			
xtlogit startwallonset p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality post911 ethsim lninc annualwallonsets startyears*, fe;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\3.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;
			
			
			



************************************************************;
*MODEL 4: wall construction pooled logit;
************************************************************;

#delimit;
logit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , robust cl(leaderid);
	
	gen sample4 = e(sample);

	
	*Export model
		*#delimit;
		*outreg2 using "C:\Users\Chris\OneDrive\Desktop\Results\4.xls", 
		*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
		*e(all)  excel replace;

	

	



************************************************************;
*MODEL 5: wall construction random effects;
************************************************************;
#delimit;
xtlogit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , re;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\5.xls", 
			**alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;	

			
			
	
*********************************************************	;	
*MODEL 6: 	wall construction fixed effects	;
*********************************************************;
	
#delimit;			
xtlogit wallconstruction p_builder  right lnpop lnref democracy  neighcivwar  neighdem   neighcount  cwinc lninequality ethsim lninc annualwallonsets  post911 wallconstructionyears* , fe;
			*outreg2 using "C:\Users\chris\OneDrive\Desktop\Results\6.xls", 
			*alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) bdec(2) sdec(2)
			*e(all)  excel replace;

			
			
log close;






			